@@ -35,7 +35,7 @@ struct child {
   struct child c;
   struct parent p;
   double SumehMin, SumegMin,  Ethresh, Cuteg, Cutneg;
-  int Np, NoOfLowE, NLowCounter, NhMin, NgMin;
+  int Np, NoOfLowE, NLowCounter, NhMin, NgMin, HowFlesh;
 // next ist integer in Fortran;
   fstream  Wdev, Mdev, Rdev;
 
